@@ -1,17 +1,16 @@
 library(stringr)
 library(dplyr)
-source("R/format_data_for_functions.R")
+# source("R/format_data_for_functions.R")
 
 seedmatrix<-function(censoredtable, Xlowerbound, Xupperbound, Ylowerbound, Yupperbound){
 
-# ################################################################################## functions that help format data first
-  #The findtypeofcensoring_univariatetable Function list the type of censoring in a provided censored frequency table
-  #Type_of_Censoring (L1 (<), L2 (<=), I (-), G1 (>), G2 (>= or +), or U (no censoring)), and Censor_Number (category value corresponding to censoring value)
+# ################################################################################## start functions that help format data first
   
-  findtypeofcensoring_univariatetable<-function (contingencytable){
+  #The findtypeofcensoring_univariatetable function regonizes the symbols and divides a frequency table up into the 6 censored cases
+  findtypeofcensoring_univariatetable<-function (univariatefreqtable){
     
     #making a dataframe from the category case (column one)
-    cases<-data.frame(contingencytable)
+    cases<-data.frame(univariatefreqtable)
     cases<-cases[1]
     #relabeled column with censoring as Censoring_Symbol
     names(cases) <- c("Censoring_Symbol")
@@ -29,6 +28,7 @@ seedmatrix<-function(censoredtable, Xlowerbound, Xupperbound, Ylowerbound, Yuppe
     
     # remove numbers from censoring_symbol column
     cases$Censoring_Symbol<-gsub('[0-9]+', '', cases$Censoring_Symbol)
+    cases$Censoring_Symbol<-gsub('\\.', '', cases$Censoring_Symbol)
     
     #named the symbols allowed in model
     L1 <- c("<")
@@ -43,7 +43,7 @@ seedmatrix<-function(censoredtable, Xlowerbound, Xupperbound, Ylowerbound, Yuppe
     G2a<-c("[+]")
     G2b<-c("GE")
     
-    # remove any spaces found in symbol column 
+    # remove any spaces found in symbol column
     cases$Censoring_Symbol<-gsub('\\s+', '', cases$Censoring_Symbol)
     
     #look to see if these symbols are in the provided table
@@ -93,7 +93,7 @@ seedmatrix<-function(censoredtable, Xlowerbound, Xupperbound, Ylowerbound, Yuppe
     #listing the no censoring cases as "U"
     cases$Type_of_Censoring[cases$Type_of_Censoring==""]<-"U"
     
-    #put in errors to let users know that there can't be duplicates of Greater than or Less than 
+    #put in errors to let users know that there can't be duplicates of Greater than or Less than
     if(length(grep("G1", cases$Type_of_Censoring))>1) stop ('Censored table can only have 1 greater than (> or G) category')
     if(length(grep("G2", cases$Type_of_Censoring))>1) stop ('Censored table can only have 1 greater than or equal to (>= or GE) category')
     if(length(grep("L2", cases$Type_of_Censoring))>1) stop ('Censored table can only have 1 less than or equal to (<= or LE) category')
@@ -102,29 +102,19 @@ seedmatrix<-function(censoredtable, Xlowerbound, Xupperbound, Ylowerbound, Yuppe
     if(length(grep("L1", cases$Type_of_Censoring))==1 && length(grep("L2", cases$Type_of_Censoring))==1) stop ('Censored table can not  have both a less than (< or L) category and a less than or equal to category (<= or LE)')
     if(length(grep("G1", cases$Type_of_Censoring))==1 && length(grep("G2", cases$Type_of_Censoring))==1) stop ('Censored table can not have both a greater than (< or G) category and a greater than or equal to category (<= or GE)')
     
-    
-    
     return (cases)} #end findtypeofcensoring_univariatetable function
   
   #####
   #####
-  #####
   
   #The fixdata_univariatecase function regonizes the symbols and divides a frequency table up into the 6 censored cases
-  #This is a formatting data function 
+  #This is a formatting data function
   #This uses the findtypeofcensoring_univariatetable function
-  #Requirement of lower and upper bounds
-  #The lower bound provided will be used in calculating a right shift and upper bound for truncation
   
-  fixdata_univariatecase<-function(contingencytable, upperbound, quasipoisson_phi) {
-    
-    # conduct findtypeofcensoring_univariatetable function on data 
-    cases<-findtypeofcensoring_univariatetable(data.frame(contingencytable))
-    
-    # stop if upperbound is smaller than largest number in table
-    largestnumintable<-max(as.numeric(unlist(regmatches(cases$Censor_Number, gregexpr("[[:digit:]]+", cases$Censor_Number)))))
-    if(largestnumintable>upperbound) stop ('Upperbound needs to be larger than or equal to its largest corresponding category number')
+  fixdata_univariatecase<-function(univariatefreqtable) {
     
+    # conduct findtypeofcensoring_univariatetable function on data
+    cases<-findtypeofcensoring_univariatetable(data.frame(univariatefreqtable))
     
     #gives a row number for each of the 6 censoring types
     lo1<-as.numeric(which(cases$Type_of_Censoring=='L1'))
@@ -137,12 +127,12 @@ seedmatrix<-function(censoredtable, Xlowerbound, Xupperbound, Ylowerbound, Yuppe
     #finding what number corresponds to the freqency value based off type of censoring
     #put as.numeric and as.character to help with format
     #R was changing decimals to whole numbers without putting as.numeric and as.character
-    countl1<-as.numeric(as.character(contingencytable[lo1,2]))
-    countl2<-as.numeric(as.character(contingencytable[lo2,2]))
-    counti<-as.numeric(as.character(contingencytable[inte,2]))
-    countg1<-as.numeric(as.character(contingencytable[gre1,2]))
-    countg2<-as.numeric(as.character(contingencytable[gre2,2]))
-    counte<-as.numeric(as.character(contingencytable[ex,2]))
+    countl1<-as.numeric(as.character(univariatefreqtable[lo1,2]))
+    countl2<-as.numeric(as.character(univariatefreqtable[lo2,2]))
+    counti<-as.numeric(as.character(univariatefreqtable[inte,2]))
+    countg1<-as.numeric(as.character(univariatefreqtable[gre1,2]))
+    countg2<-as.numeric(as.character(univariatefreqtable[gre2,2]))
+    counte<-as.numeric(as.character(univariatefreqtable[ex,2]))
     
     #finding what number (in the Censor_Number) corresponds to the censor type
     #values listed in cases$Censor_Number[] are factors
@@ -169,42 +159,44 @@ seedmatrix<-function(censoredtable, Xlowerbound, Xupperbound, Ylowerbound, Yuppe
       interval<-unname(cbind(interval,counti))
     } else {interval=NULL}
     
-
+    # testing to see if intervals are closed..
+    if (length(interval)!=0){
+      intervalclosed<-as.vector(interval[,1:2]) 
+      if (any(duplicated(intervalclosed))==TRUE) stop (paste(intervalclosed[which(duplicated(intervalclosed)==TRUE)],
+                                                             'is repeated in different - or I categories and this is not allowed (i.e. need closed intervals)'))
+    }
+    
+    
     #return values for later use
     final<-list(leftcensored1=lower1,leftcensored2=lower2, nocensored=exact,
                 rightcensored1=greater1,
-                rightcensored2=greater2, intervalcensored=interval,
-                upperbound=upperbound,
-                quasipoisson_phi = quasipoisson_phi)
-    
-    # report error.. 
-    if(length(final$leftcensored2)!=0) {leftcensored2value<-final$leftcensored2[1,1]} else {leftcensored2value=-1}
-    if(length(final$intervalcensored)!=0) {intervalvalues<-final$intervalcensored[,c(1,2)]} else {intervalvalues=-2}
-    if(length(final$rightcensored2)!=0) {rightcensored2value<-final$rightcensored2[1,1]} else {rightcensored2value=-3}
-    if(length(final$nocensored)!=0) {nocensored<-final$nocensored[1,]} else {nocensored = -4}
-    
-    # add error if user does not do interval censoring correctly 
-    if(any(intervalvalues==leftcensored2value) || 
-       any(intervalvalues==rightcensored2value) ||
-       any(intervalvalues==nocensored)) stop ('Check interval censoring.')
-    
+                rightcensored2=greater2, intervalcensored=interval
+                # lowerbound = lowerbound,
+                # upperbound=upperbound
+    )
     
     #replacing any negative numbers with 0
     #there might be negative numbers, but these negative values will cause error in the likelihood function
     final<-rapply(final,function(x) ifelse(x<0,0,x), how = "replace")
+    
+    # add errors
+    if(length(final$leftcensored2)!= 0 && length(final$intervalcensored) != 0 &&
+       final$leftcensored2[1,1] == final$intervalcensored[1,1]) stop ('Censored table can not have the same number in both the <= or LE category and the - or I category (i.e. need closed intervals)')
+    
+    if(length(final$rightcensored2)!= 0 && length(final$intervalcensored) != 0 &&
+       final$rightcensored2[1,1] == final$intervalcensored[nrow(final$intervalcensored),2]) stop ('Censored table can not have the same number in both the >= or GE or + category and the - or I category (i.e. need closed intervals)')
+    
     return(final)
   } #end fixdata_univariatecase function
   
-  #####
-  #####
   
-  # ################################################################################## end functions that help format data first
+# ################################################################################## end functions that help format data first
   
   
 # looking at provided table
 # griding the row and col names 
-rnames<-findtypeofcensoring_univariatetable(row_marginal(censoredtable))$Type_of_Censoring
-cnames<-findtypeofcensoring_univariatetable(column_marginal(censoredtable))$Type_of_Censoring
+rnames<-findtypeofcensoring_univariatetable(row.marginal(censoredtable))$Type_of_Censoring
+cnames<-findtypeofcensoring_univariatetable(column.marginal(censoredtable))$Type_of_Censoring
 # tn = table names
 tn_expaned<-expand.grid(rnames, cnames)
 
@@ -219,6 +211,13 @@ Inside<-matrix(as.matrix(lcgone), dim(data.frame(lcgone))*dim(data.frame(lcgone)
 #r emoving commas from inside of table
 inside<-str_replace_all(Inside,",","")
 
+suminside<-sum(as.numeric(inside))
+
+# make probabilities
+if (suminside != 1) {inside<-as.numeric(inside)/sum(as.numeric(inside))}
+
+
+
 # put inside table with corresponding rows and cols
 tn_expaned$repvar<-inside
 names(tn_expaned)<-c("row", "col", "inside")
@@ -227,8 +226,8 @@ tn_expaned$rowcol<-paste(tn_expaned$row, tn_expaned$col, sep = "_")
 tn_expaned<-tn_expaned[3:4]
 
 # find numbers for each name
-rnumb<-findtypeofcensoring_univariatetable(row_marginal(censoredtable))$Censor_Number
-cnumb<-findtypeofcensoring_univariatetable(column_marginal(censoredtable))$Censor_Number
+rnumb<-findtypeofcensoring_univariatetable(row.marginal(censoredtable))$Censor_Number
+cnumb<-findtypeofcensoring_univariatetable(column.marginal(censoredtable))$Censor_Number
 # remove spaces from the numbers
 rnumb<-gsub(" ", "", rnumb) 
 cnumb<-gsub(" ", "", cnumb) 
@@ -243,8 +242,8 @@ tn_expaned<-cbind(tn_expaned, "Censoring_Numbers" = paste(tn_expaned$rowcol, tn_
 
 # run function to know cases of the provided table
 # quasipoisson_phiX and quasipoisson_phiY doesn't actually equal one.. just a place filler
-repx<-fixdata_univariatecase(row_marginal(censoredtable), Xupperbound, 1)
-repy<-fixdata_univariatecase(column_marginal(censoredtable),Yupperbound, 1)
+repx<-fixdata_univariatecase(row.marginal(censoredtable))
+repy<-fixdata_univariatecase(column.marginal(censoredtable))
 
 # uncensored table names expaned grid
 tn_expand_new<-expand.grid(Xlowerbound:Xupperbound, Ylowerbound:Yupperbound)
@@ -594,6 +593,7 @@ seed[insidefortable[i,1], insidefortable[i,2]]<-as.numeric(insidefortable[i,3])
 
 colnames(seed)<-Ylowerbound:Yupperbound
 row.names(seed)<-Xlowerbound:Xupperbound
+seedp<-seed/sum(seed)
 
-return(seed)
+return(list("Exact"=seed,"Probabilities"=seedp))
 } # end seed function 
\ No newline at end of file
